Crate pslink_locales

Crate pslink_locales 

This modules contains the parts for making the app translatable.

Structs

I18n
A struct containing the data, functions and the current language to query the localized strings.